==> hibernate-search-engine-6.0.3.Final-sources.jar: org/hibernate/search/engine/reporting/EntityIndexingFailureContext.java <==
/*
 * Hibernate Search, full-text search for your domain model
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
package org.hibernate.search.engine.reporting;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Contextual information about a failure to index entities.
 */
public class EntityIndexingFailureContext extends FailureContext {

	public static Builder builder() {
		return new Builder();
	}

	private final List<Object> entityReferences;

	private EntityIndexingFailureContext(Builder builder) {
		super( builder );
		this.entityReferences = builder.entityReferences == null
				? Collections.emptyList() : Collections.unmodifiableList( builder.entityReferences );
	}

	/**
	 * @return A list of references to entities that may not be indexed correctly as a result of the failure.
	 * Never {@code null}, but may be empty.
	 * Use {@link Object#toString()} to get a textual representation of each reference,
	 * or cast it to the mapper-specific {@code EntityReference} type.
	 */
	public List<Object> entityReferences() {
		return entityReferences;
	}

	public static class Builder extends FailureContext.Builder {

		private List<Object> entityReferences;

		private Builder() {
		}

		public void entityReference(Object entityReference) {
			if ( entityReferences == null ) {
				entityReferences = new ArrayList<>();
			}
			entityReferences.add( entityReference );
		}

		@Override
		public EntityIndexingFailureContext build() {
			return new EntityIndexingFailureContext( this );
		}
	}
}

==> hibernate-search-engine-6.1.6.Final-sources.jar: org/hibernate/search/engine/reporting/EntityIndexingFailureContext.java <==
/*
 * Hibernate Search, full-text search for your domain model
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
package org.hibernate.search.engine.reporting;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Contextual information about a failure to index entities.
 */
public class EntityIndexingFailureContext extends FailureContext {

	public static Builder builder() {
		return new Builder();
	}

	private final List<Object> entityReferences;

	private EntityIndexingFailureContext(Builder builder) {
		super( builder );
		this.entityReferences = builder.entityReferences == null
				? Collections.emptyList() : Collections.unmodifiableList( builder.entityReferences );
	}

	/**
	 * @return A list of references to entities that may not be indexed correctly as a result of the failure.
	 * Never {@code null}, but may be empty.
	 * Use {@link Object#toString()} to get a textual representation of each reference,
	 * or cast it to the mapper-specific {@code EntityReference} type.
	 */
	public List<Object> entityReferences() {
		return entityReferences;
	}

	@Override
	public String toString() {
		return "EntityIndexingFailureContext{" +
				"entityReferences=" + entityReferences +
				", throwable=" + throwable +
				", failingOperation=" + failingOperation +
				'}';
	}

	public static class Builder extends FailureContext.Builder {

		private List<Object> entityReferences;

		private Builder() {
		}

		public void entityReference(Object entityReference) {
			if ( entityReferences == null ) {
				entityReferences = new ArrayList<>();
			}
			entityReferences.add( entityReference );
		}

		@Override
		public EntityIndexingFailureContext build() {
			return new EntityIndexingFailureContext( this );
		}
	}
}
